summaryrefslogtreecommitdiffstats
path: root/tdeparts/statusbarextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeparts/statusbarextension.h')
-rw-r--r--tdeparts/statusbarextension.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdeparts/statusbarextension.h b/tdeparts/statusbarextension.h
index fa635a12b..8e6ea062d 100644
--- a/tdeparts/statusbarextension.h
+++ b/tdeparts/statusbarextension.h
@@ -27,7 +27,7 @@
#include <tdelibs_export.h>
class KStatusBar;
-class KMainWindow;
+class TDEMainWindow;
class TQEvent;
namespace KParts
@@ -87,7 +87,7 @@ namespace KParts
void removeStatusBarItem( TQWidget * widget );
/**
* @return the statusbar of the KMainWindow in which this part is currently embedded.
* WARNING: this could return 0L
*/
KStatusBar* statusBar() const;
@@ -95,7 +95,7 @@ namespace KParts
/**
* This allows the hosting application to set a particular KStatusBar
* for this part. If it doesn't do this, the statusbar used will be
* the one of the KMainWindow in which the part is embedded.
* Konqueror uses this to assign a view-statusbar to the part.
* The part should never call this method!
*/
@@ -87,7 +87,7 @@ namespace KParts
void removeStatusBarItem( TQWidget * widget );
/**
- * @return the statusbar of the KMainWindow in which this part is currently embedded.
+ * @return the statusbar of the TDEMainWindow in which this part is currently embedded.
* WARNING: this could return 0L
*/
@@ -95,7 +95,7 @@ namespace KParts
* This allows the hosting application to set a particular KStatusBar
* for this part. If it doesn't do this, the statusbar used will be
- * the one of the KMainWindow in which the part is embedded.
+ * the one of the TDEMainWindow in which the part is embedded.
* Konqueror uses this to assign a view-statusbar to the part.
* The part should never call this method!